#! /bin/sh

###########################################################################
#   @file       woroot-create.sh
#   @copyright  Copyright 2008 David F. Elliott <dfe@tgwbd.org>
#   @description
#   Extracts files from Xcode 2.5 packages and deletes files that are
#   part of the Xcode 3.0 WebObjectsDevelopment package.

xcode25_packages_dir="/Volumes/Xcode Tools/Packages/Packages"
pkg_name="WebObjectsLegacyDevelopment"
DSTROOT=/tmp/${pkg_name}.dst

WebObjectsDevelopment_paxgz="${xcode25_packages_dir}/WebObjectsDevelopment.pkg/Contents/Archive.pax.gz"
DeveloperTools_paxgz="${xcode25_packages_dir}/DeveloperTools.pkg/Contents/Archive.pax.gz" 

# Make sure we can find the archives we need before starting
if ! test -f "${WebObjectsDevelopment_paxgz}"; then
    echo "Could not find \"${WebObjectsDevelopment_paxgz}\"" 1>&2
    exit 1
fi

if ! test -f "${DeveloperTools_paxgz}"; then
    echo "Could not find \"${DeveloperTools_paxgz}\"" 1>&2
    exit 1
fi

# Make sure DSTROOT is set (rm -rf is dangerous)
if test "x${DSTROOT}" == "x"; then
    echo "Must have a DSTROOT (e.g. /tmp/${pkg_name}.dst)" 1>&2
    exit 1
fi
if test -e "$DSTROOT"; then
    if test -d "$DSTROOT"; then
        cd "$DSTROOT"
        if test "`pwd`" == "/"; then
            echo "DSTROOT must not be the filesystem root (\"/\")" 1>&2
            exit 1
        fi
        echo "---> Removing old DSTROOT \"$DSTROOT\""
        rm -rf "$DSTROOT"
    else
        echo "DSTROOT (\"${DSTROOT}\") exists but is not a directory." 1>&2
        exit 1
    fi
fi


mkdir "$DSTROOT"
cd "$DSTROOT"

echo "---> Extracting Xcode 2.5 WebObjectsDevelopment package"
gunzip -c "${WebObjectsDevelopment_paxgz}" | pax -rv
echo "---> Extracting InterfaceBuilder.framework from Xcode 2.5 DeveloperTools package"
(
    cd Developer &&
    gunzip -c "${DeveloperTools_paxgz}" | pax -rv ./Library/Frameworks/InterfaceBuilder.framework
)

echo "---> Removing unneeded files"
while read fn; do
    rm -fv "$fn"
done <<EOF
Library/Java/Extensions/OpenBaseJDBC.jar
Library/WebObjects/lib/JavaEOTool.jar
Library/WebObjects/lib/javaeoutil.jar
Developer/Makefiles/java_makefiles/CoaxBundleIntoJar.sh
Developer/Makefiles/java_makefiles/CreateRunFiles.sh
Developer/Makefiles/java_makefiles/CreateServletEnv.sh
Developer/Makefiles/java_makefiles/J2EESDK1.3.sh
Developer/Makefiles/java_makefiles/LICENSE
Developer/Makefiles/java_makefiles/ServletEnv_web.xml
Developer/Makefiles/java_makefiles/UnixLaunch.sh
Developer/Makefiles/java_makefiles/WOBootstrap.jar
Developer/Makefiles/java_makefiles/WinLaunch.CMD
Developer/Makefiles/java_makefiles/aggregate.make
Developer/Makefiles/java_makefiles/build.make
Developer/Makefiles/java_makefiles/commands-HPUX.make
Developer/Makefiles/java_makefiles/commands-MACOS.make
Developer/Makefiles/java_makefiles/commands-NEXTSTEP.make
Developer/Makefiles/java_makefiles/commands-SOLARIS.make
Developer/Makefiles/java_makefiles/commands-WINDOWS.make
Developer/Makefiles/java_makefiles/common.make
Developer/Makefiles/java_makefiles/compatibility.make
Developer/Makefiles/java_makefiles/flags.make
Developer/Makefiles/java_makefiles/framework.make
Developer/Makefiles/java_makefiles/install.make
Developer/Makefiles/java_makefiles/installsrc.make
Developer/Makefiles/java_makefiles/javapackage.make
Developer/Makefiles/java_makefiles/platform-variables.make
Developer/Makefiles/java_makefiles/platform.make
Developer/Makefiles/java_makefiles/prebuild.make
Developer/Makefiles/java_makefiles/recursion.make
Developer/Makefiles/java_makefiles/wo-postamble.make
Developer/Makefiles/java_makefiles/wo-preamble.make
Developer/Makefiles/java_makefiles/woapp.make
Developer/Makefiles/java_makefiles/woejbframework.make
Developer/Makefiles/java_makefiles/woframework.make
Developer/Makefiles/java_makefiles/wosubproj.make
Developer/Makefiles/java_makefiles/wrapped-common.make
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects/com/webobjects/_bootstrap/WOBootstrap.java
Library/Application Support/Apple/Developer Tools/WebObjects Support/AssembleApplication.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/AssembleFramework.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/AssembleServletEnv.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/CoaxBundleIntoJar.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/ComputeTargetClasspath.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/CopyJavaClasses.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/CopyResources.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/CreateRunFiles.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/CreateServletEnv.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/DefineFileLocations.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/InstallJarBundle.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/J2EESDK1.3.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/ServletEnv_web.xml
Library/Application Support/Apple/Developer Tools/WebObjects Support/SetPermissions.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/UnixLaunch.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/UnixLaunchClient.sh
Library/Application Support/Apple/Developer Tools/WebObjects Support/WinLaunch.CMD
Library/Application Support/Apple/Developer Tools/WebObjects Support/WOBootstrap.jar
Library/Application Support/Apple/Developer Tools/WebObjects Support/jboss-web.xml
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/Application.java
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/DirectAction.java
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/Main.api
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/Main.java
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/Properties
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/Session.java
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/WOAfile.icns
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Framework/Properties
System/Library/Frameworks/JavaWebObjects.framework/Resources/Properties
System/Library/WebObjects/JavaApplications/EOServer.jar
System/Library/WebObjects/Temporary/OpenBaseTarFiles/OpenBaseTarFiles
EOF

echo "---> Removing unneeded bundles"
while read fn; do
    rm -rf "$fn" && echo "$fn"
done <<EOF
Developer/Applications/WebObjects/WebServicesAssistant.app
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects/Component.pbfiletemplate
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects/EOModel.pbfiletemplate
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects/Java Class.pbfiletemplate
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/Main.wo
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application/WebObjects Application.pbproj
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Framework/WebObjects Framework.pbproj
System/Library/Frameworks/JavaEOTool.framework
System/Library/WebObjects/JavaApplications/JavaPlaybackManager.woa
System/Library/WebObjects/JavaApplications/javaeoutil.woa
System/Library/WebObjects/JavaApplications/EOServer.woa
EOF

echo "---> Removing unneeded directories"
while read fn; do
    rmdir "$fn" && echo "$fn"
done <<EOF
System/Library/Frameworks/JavaWebObjects.framework/Resources
System/Library/Frameworks/JavaWebObjects.framework
System/Library/WebObjects/Temporary/OpenBaseTarFiles
System/Library/WebObjects/Temporary
System/Library/WebObjects/JavaApplications
Library/WebObjects/lib
Library/WebObjects
Library/Java/Extensions
Library/Java
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Framework
Library/Application Support/Apple/Developer Tools/WebObjects Support/WebObjects Application
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects/com/webobjects/_bootstrap
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects/com/webobjects
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects/com
Library/Application Support/Apple/Developer Tools/File Templates/WebObjects
Library/Application Support/Apple/Developer Tools/File Templates
Developer/Makefiles/java_makefiles
Developer/Makefiles
EOF

